<div align="center">
  <img src="https://jugit.fz-juelich.de/IBG-1/ModSim/uNAC/-/raw/multi_tools/assets/unac_logo.svg" width=200 alt="logo">
</div>

# uNAC - the universal natural abundace correction tool

![pipeline status](https://jugit.fz-juelich.de/IBG-1/ModSim/uNAC/badges/multi_tools/pipeline.svg) ![coverage](https://jugit.fz-juelich.de/IBG-1/ModSim/uNAC/badges/multi_tools/coverage.svg) [![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/unac/README.html)

This tool is aimed for the correction of measurements from isotope labeling experiments.
It is currently work in progress. Stay tuned.
